# if needed
import ssl
ssl._create_default_https_context = ssl._create_unverified_context

# Section 1 - Loading our Libraries
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib.dates import DateFormatter
import matplotlib.ticker as ticker

# Section 2 - Loading and Selecting Data
df = pd.read_csv('https://raw.githubusercontent.com/datasets/covid-19/master/data/countries-aggregated.csv',
                 parse_dates=['Date'])
countries = ['Canada', 'Germany', 'United Kingdom', 'US', 'France', 'China', "Switzerland"]
df = df[df['Country'].isin(countries)]

# Section 3 - Creating a Summary Column
df['Cases'] = df[['Confirmed', 'Recovered', 'Deaths']].sum(axis=1)
# df['Cases'] = df[['Recovered']].sum(axis=1)
# df['Cases'] = df[['Confirmed']].sum(axis=1)
# df['Cases'] = df[['Deaths']].sum(axis=1)

# Section 4 - Restructuring our Data
print(df)
df = df.pivot(index='Date', columns='Country', values='Cases')
covid = df.copy()
print(df)

# Section 5 - Calculating Rates per 100,000
populations = {'Canada': 37664517, 'Germany': 83721496, 'United Kingdom': 67802690, 'US': 330548815, 'France': 65239883,
               'China': 1438027228, "Switzerland": 8570000}
percapita = covid.copy()
for country in list(percapita.columns):
    percapita[country] = percapita[country] / populations[country] * 100000

# Section 6 - Generating Colours and Style
colors = {'Canada': '#045275', 'China': '#089099', 'France': '#7CCBA2', 'Germany': '#FCDE9C', 'US': '#DC3977',
          'United Kingdom': '#7C1D6F', "Switzerland": "#ff0000"}
plt.style.use('fivethirtyeight')

# Section 7 - Creating the Visualization
plot = covid.plot(figsize=(12, 8), color=list(colors.values()), linewidth=5, legend=False)
ax = plt.gca()
plot.yaxis.set_major_formatter(ticker.StrMethodFormatter('{x:,.0f}'))
plot.grid(color='#d4d4d4')
plot.set_xlabel('Date')
plot.set_ylabel('# of Cases')

# Section 8 - Assigning Colour
for country in list(colors.keys()):
    plot.text(x=covid.index[-1], y=covid[country].max(), c=colors[country], s=country, weight='bold')

# Section 9 - Adding Labels
plot.text(x=0, y=1.1, s="COVID-19 Cases by Country", fontsize=23, weight='bold', alpha=.75, transform=ax.transAxes)
plot.text(x=covid.index[1], y=int(covid.max().max()) + 15000,
          s="For the USA, China, Germany, France, United Kingdom, and Canada\nIncludes Current Cases, Recoveries, and Deaths",
          fontsize=16, alpha=.75)
plot.text(x=0, y=0,
          s='datagy.io                      Source: https://github.com/datasets/covid-19/blob/master/data/countries-aggregated.csv',
          fontsize=10, transform=ax.transAxes)

percapitaplot = percapita.plot(figsize=(12, 8), color=list(colors.values()), linewidth=5, legend=False)
ax = plt.gca()
percapitaplot.grid(color='#d4d4d4')
percapitaplot.set_xlabel('Date')
percapitaplot.set_ylabel('# of Cases per 100,000 People')
for country in list(colors.keys()):
    percapitaplot.text(x=percapita.index[-1], y=percapita[country].max(), c=colors[country], s=country, weight='bold')
percapitaplot.text(x=0, y=1.1, s="Per Capita COVID-19 Cases by Country", fontsize=23, weight='bold', alpha=.75,
                   transform=ax.transAxes)
percapitaplot.text(x=percapita.index[1], y=percapita.max().max() + 10,
                   s="For the USA, China, Germany, France, United Kingdom, and Canada\nIncludes Current Cases, Recoveries, and Deaths",
                   fontsize=16, alpha=.75)
percapitaplot.text(x=0, y=0,
                   s='datagy.io                      Source: https://github.com/datasets/covid-19/blob/master/data/countries-aggregated.csv',
                   fontsize=10, transform=ax.transAxes)
plt.show()
